==> libsock-1.0.0.tgz: include/libsock/libsock.h <==
/******************************************************************************
 *
 * Copyright (C) 1996-2000 Jason Evans <jasone@canonware.com>.
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice(s), this list of conditions and the following disclaimer as
 *    the first lines of this file unmodified other than the possible
 *    addition of one or more copyright notices.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice(s), this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER(S) ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER(S) BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************
 *
 * Version: 1.0.0
 *
 * Master header file for libsock.
 *
 ******************************************************************************/

#ifdef __cplusplus
extern  "C" {
#endif

#ifndef _LIBSOCK_H_
#define _LIBSOCK_H_

#define _LIBSOCK_VERSION "1.0.0"

/* Causes verbose I/O-related output. */
/*  #define _LIBSOCK_CONFESS */

/* Project headers to always be included. */

#include "libsock_incs.h"

/* Opaque type. */
typedef struct cw_libsock_s cw_libsock_t;

/* Global variable. */
extern cw_libsock_t	*g_libsock;

cw_bool_t	libsock_init(cw_uint32_t a_max_fds, cw_uint32_t a_bufc_size,
    cw_uint32_t a_max_spare_bufcs);
void		libsock_shutdown(void);
cw_bufc_t	*libsock_spare_bufc_get(void);
cw_bool_t	libsock_in_notify(cw_mq_t *a_mq, int a_sockfd);
	
#endif /* _LIBSOCK_H_ */

#ifdef __cplusplus
};

#endif

==> libsock-1.2.0.tgz: include/libsock/libsock.h <==
/******************************************************************************
 *
 * Copyright (C) 1996-2001 Jason Evans <jasone@canonware.com>.
 * All rights reserved.
 * 
 * Redistribution and use in source and binary forms, with or without
 * modification, are permitted provided that the following conditions
 * are met:
 * 1. Redistributions of source code must retain the above copyright
 *    notice(s), this list of conditions and the following disclaimer as
 *    the first lines of this file unmodified other than the possible
 *    addition of one or more copyright notices.
 * 2. Redistributions in binary form must reproduce the above copyright
 *    notice(s), this list of conditions and the following disclaimer in
 *    the documentation and/or other materials provided with the
 *    distribution.
 * 
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDER(S) ``AS IS'' AND ANY
 * EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE
 * IMPLIED WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR
 * PURPOSE ARE DISCLAIMED.  IN NO EVENT SHALL THE COPYRIGHT HOLDER(S) BE
 * LIABLE FOR ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR
 * CONSEQUENTIAL DAMAGES (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF
 * SUBSTITUTE GOODS OR SERVICES; LOSS OF USE, DATA, OR PROFITS; OR
 * BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON ANY THEORY OF LIABILITY,
 * WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT (INCLUDING NEGLIGENCE
 * OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS SOFTWARE,
 * EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 *
 ******************************************************************************
 *
 * Version: 1.2.0
 *
 * Master header file for libsock.
 *
 ******************************************************************************/

#ifdef __cplusplus
extern  "C" {
#endif

#ifndef _LIBSOCK_H_
#define _LIBSOCK_H_

#define _LIBSOCK_VERSION "1.2.0"

/* Causes verbose I/O-related output. */
/*  #define _LIBSOCK_CONFESS */

/* Project headers to always be included. */

#include "libsock_incs.h"

/* Opaque type. */
typedef struct cw_libsock_s cw_libsock_t;

/* Global variable. */
extern cw_libsock_t	*g_libsock;

void		libsock_init(cw_uint32_t a_max_fds, cw_uint32_t a_bufc_size,
    cw_uint32_t a_max_spare_bufcs);
void		libsock_shutdown(void);
cw_bufc_t	*libsock_spare_bufc_get(void);
void		libsock_in_notify(cw_mq_t *a_mq, int a_sockfd);
	
#endif /* _LIBSOCK_H_ */

#ifdef __cplusplus
};

#endif
